This function calculates true positive rate, false positive rate, false negative rate, false positive count, and sensitivity
count_stats( gold_standard, predicted_segmentation, k = Inf, percent_overlap = NULL, verbose = TRUE )
| gold_standard | Gold standard segmentation mask of class nifti |
|---|---|
| predicted_segmentation | Predicted segmentation mask volume of class nifti |
| k | Minimum number of voxels for a segmentation cluster/component |
| percent_overlap | Proportion of gold standard segmentation to be overlapped by predicted |
| verbose | Logical indicating printing diagnostic output |
Matrix of results