Usage
.fitMCMC(data, inits = NULL, iter = 250000, burn = 50000, thin = 1, tune = 100, outfile = basename(tempfile(tmpdir = ".", fileext = ".dat")), alternative = "greater", UPPER = 0.5, LOWER = 0.15, FAST = TRUE, EXPRATE = 1e-04, pXi = c(1, 1), seed = 10)
Arguments
data
a list with elements names 'n.stim' and 'n.unstim', the
stimulated and unstimulated counts. Must be at least of dimension 2.
inits
the initialization parameters for the MCMC routine. Can be
initialized from MDMix with initonly=TRUE.
iter
the number of Mote Carlo iterations
burn
the number of burn-in iterations
thin
The thinning interval
tune
the number of iterations used for tuning the step size
outfile
the output file name
alternative
either 'greater' or 'not equal' for fitting the one-sided
or two-sided MIMOSA model, respectively.
UPPER
tuning parameter for the upper bound on the acceptance ratio of
each paramter
LOWER
tuning parmeter for the lower bound on the acceptance ratio of
each paramter
FAST
TRUE,FALSE. Use the heuristic (FAST=TRUE) for fitting a
one-sided model rather than recomputing the normalization constant via MCMC
for each step.
EXPRATE
the mean of the prior distribution for the model hyperparameters.
pXi
is the prior on the w, beta(1,1) by default).